LayoutModEvent

Enum LayoutModEvent 

pub enum LayoutModEvent {
    ClefChange {
        sign: ClefSign,
        pos: i32,
        octave: i32,
    },
    Transposition {
        pitch: Pitch,
    },
}

Variants



ClefChange

Fields

pos: i32

The staff position of the clef, in increments of half a staff line, starting at the middle line.

Examples:

  • Treble: -2
  • Bass: 2
  • Alto: 0
octave: i32

The octave transposition for a clef.

Usually 0, but changes for things like a “treble_8” clef (where it would be -8).



Transposition

Fields

pitch: Pitch

Implementations

Source

impl LayoutModEvent

pub fn new_treble_clef() -> LayoutModEvent

A helper function for creating a basic treble clef.

pub fn new_bass_clef() -> LayoutModEvent

A helper function for creating a basic bass clef.

pub fn new_alto_clef() -> LayoutModEvent

A helper function for creating a basic alto clef.