Crate cdnz

Crate cdnz 

CDNZ

CDNZ is an open data format for storing music, primarily intended for use by Cadenza, but can also be used elsewhere. This crate is both a Rust implementation, and a specification.

The format is partly inspired by MNX and LilyPond, and can be converted to LilyPond code using this lib. Cadenza can also convert it to LilyPond and then PDF, SVG, and MIDI.

Specification

This crate also partly functions as the specification of the CDNZ format.

In the future, a solid specification will be provided. In the meantime, the Rust documentation will have to suffice.

License

The CDNZ spec and docs, and this Rust implementation, are both licensed under either of:

at your option.

Re-exports

pub use cdnz_serde::VersionInfo;

Modules

cdnz_serde
lilypond
upgrade
This module focuses on upgrading old CDNZ files to the latest version.

Structs

Book
Bpm
Cdnz
The root object of a CDNZ file.
Duration
GlobalData
Header
Metadata
Metadata about the CDNZ file in question.
Part
PersonInfo
Pitch
Position
Staff
StaffGroup

Enums

ClefSign
GlobalModEvent
KeyMode
Layout
LocalModEvent
RhythmicEvent