pub enum LayoutModEvent {
ClefChange {
sign: ClefSign,
pos: i32,
octave: i32,
},
Transposition {
pitch: Pitch,
},
}Variants
ClefChange
Fields
Transposition
Implementations
Sourceimpl LayoutModEvent
impl LayoutModEvent
Sourcepub fn new_treble_clef() -> LayoutModEvent
pub fn new_treble_clef() -> LayoutModEvent
A helper function for creating a basic treble clef.
Sourcepub fn new_bass_clef() -> LayoutModEvent
pub fn new_bass_clef() -> LayoutModEvent
A helper function for creating a basic bass clef.
Sourcepub fn new_alto_clef() -> LayoutModEvent
pub fn new_alto_clef() -> LayoutModEvent
A helper function for creating a basic alto clef.